package cc.fascinated.model.leaderboard;

import cc.fascinated.common.ScoreSaberUtils;
import cc.fascinated.model.token.ScoreSaberLeaderboardToken;
import lombok.AllArgsConstructor;
import lombok.Getter;

/**
 * @author Fascinated (fascinated7)
 */
@AllArgsConstructor
@Getter
public class Leaderboard {
    /**
     * The ID of the leaderboard.
     */
    private String id;

    /**
     * The hash of the song.
     */
    private String songHash;

    /**
     * The name of the song.
     */
    private String songName;

    /**
     * The sub name of the song.
     */
    private String songSubName;

    /**
     * The author of the song.
     */
    private String songAuthorName;

    /**
     * The mapper of the song.
     */
    private String levelAuthorName;

    /**
     * The difficulty of the song.
     */
    private Difficulty difficulty;

    /**
     * The star rating for this leaderboard.
     */
    private double stars;
    /**
     * The cover image for this leaderboard.
     */
    private String coverImage;

    /**
     * Constructs a new {@link Leaderboard} object
     * from a {@link ScoreSaberLeaderboardToken} object.
     *
     * @param token The token to construct the object from.
     * @return The leaderboard.
     */
    public static Leaderboard getFromScoreSaberToken(ScoreSaberLeaderboardToken token) {
        return new Leaderboard(
                token.getId(),
                token.getSongHash(),
                token.getSongName(),
                token.getSongSubName(),
                token.getSongAuthorName(),
                token.getLevelAuthorName(),
                new Difficulty(
                        ScoreSaberUtils.parseDifficulty(token.getDifficulty().getDifficulty()),
                        token.getDifficulty().getDifficultyRaw()
                ),
                token.getStars(),
                token.getCoverImage()
        );
    }
}
